@@ -48,7 +48,7 @@ def pushImage(config_json):
                 print(line['error'])
                 client.images.remove(common.get_docker_registry() + '/' + path + ':latest')
                 myLogger.error_logger('Tool upload failed')
-            print(line)
+            print(line['progressDetail'])
         try:
             common.post(url=common.get_cloud_base_url() + '/tool/create', data={
                 'name': config_json['name'],
@@ -125,6 +125,7 @@ def checkToolConfig(toolConfig):
 
     outLabelSet = set()
     outFileKeyList = set()
+    outDirFileSet = set()
     outFileKeyLength = 0
     toolOutputFileList = toolConfig['outputs']
     if len(toolOutputFileList) == 0:
@@ -143,6 +144,21 @@ def checkToolConfig(toolConfig):
             outFileKeyList.add(outFile['key'])
             outFileKeyLength = outFileKeyLength + 1
 
+        if outFile['key'] == '' and '*' in outFile['name']:
+            if outFile['name'].startswith('*.'):
+                out_file_str_list = outFile['name'].split('.')
+                if len(out_file_str_list) == 2:
+                    myLogger.error_logger('OutName error')
+                else:
+                    if out_file_str_list[1] == '':
+                        myLogger.error_logger('OutName error')
+                    else:
+                        if outFile['name'] in outDirFileSet:
+                            myLogger.error_logger('Output file name repeat')
+                        else:
+                            outDirFileSet.add(outFile['name'])
+
+
     if inFileKeyLength != len(inFileKeyList):
         myLogger.error_logger("The input file key cannot be repeated")
     if outFileKeyLength != len(outFileKeyList):
